import * as postcss from 'postcss';
import { Diagnostics } from './diagnostics';
import { Pojo, StateParsedValue } from './types';
export declare const valueParserWarnings: {
    VALUE_CANNOT_BE_STRING(): string;
    CSS_MIXIN_FORCE_NAMED_PARAMS(): string;
};
export interface MappedStates {
    [s: string]: StateParsedValue | string | null;
}
export interface TypedClass {
    '-st-root'?: boolean;
    '-st-states'?: string[] | MappedStates;
    '-st-extends'?: string;
    '-st-variant'?: boolean;
}
export interface MixinValue {
    type: string;
    options: Array<{
        value: string;
    }> | Pojo<string>;
}
export interface ArgValue {
    type: string;
    value: string;
}
export interface ExtendsValue {
    symbolName: string;
    args: ArgValue[][] | null;
}
export declare const valueMapping: {
    from: "-st-from";
    named: "-st-named";
    default: "-st-default";
    root: "-st-root";
    states: "-st-states";
    extends: "-st-extends";
    mixin: "-st-mixin";
    variant: "-st-variant";
    compose: "-st-compose";
    theme: "-st-theme";
    global: "-st-global";
};
export declare type stKeys = keyof typeof valueMapping;
export declare const stValues: string[];
export declare const stValuesMap: Pojo<boolean>;
export declare const STYLABLE_VALUE_MATCHER: RegExp;
export declare const STYLABLE_NAMED_MATCHER: RegExp;
export declare const SBTypesParsers: {
    '-st-root'(value: string): boolean;
    '-st-variant'(value: string): boolean;
    '-st-theme'(value: string): boolean;
    '-st-global'(decl: postcss.Declaration, _diagnostics: Diagnostics): any;
    '-st-states'(value: string, decl: postcss.Declaration, diagnostics: Diagnostics): MappedStates;
    '-st-extends'(value: string): {
        ast: any;
        types: ExtendsValue[];
    };
    '-st-named'(value: string): {
        [key: string]: string;
    };
    '-st-mixin'(mixinNode: postcss.Declaration, strategy: (type: string) => "named" | "args", diagnostics?: Diagnostics | undefined): {
        type: string;
        options: Pojo<string> | {
            value: string;
        }[];
    }[];
    '-st-compose'(composeNode: postcss.Declaration, diagnostics: Diagnostics): string[];
};
export declare function groupValues(nodes: any[], divType?: string): any[];
export declare function listOptions(node: any): any[];
//# sourceMappingURL=stylable-value-parsers.d.ts.map