"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var stylable_value_parsers_1 = require("../src/stylable-value-parsers");
var parseExtends = stylable_value_parsers_1.SBTypesParsers[stylable_value_parsers_1.valueMapping.extends];
describe('SBTypesParsers.extends', function () {
    it('should parse type extends', function () {
        chai_1.expect(parseExtends('Button').types).to.eql([
            { args: null, symbolName: 'Button' }
        ]);
    });
    it('should parse function extends with no arguments', function () {
        chai_1.expect(parseExtends('Button()').types).to.eql([
            { args: [], symbolName: 'Button' }
        ]);
    });
    it('should parse type extends with value arguments separated by comma', function () {
        chai_1.expect(parseExtends('Button(1px solid, red)').types).to.eql([
            {
                args: [
                    [
                        { type: 'word', value: '1px' },
                        { type: 'space', value: ' ' },
                        { type: 'word', value: 'solid' }
                    ],
                    [
                        { type: 'word', value: 'red' }
                    ]
                ],
                symbolName: 'Button'
            }
        ]);
    });
    it('should parse multiple extends separated by space', function () {
        chai_1.expect(parseExtends('Button(1px solid, red) Mixin').types).to.eql([
            {
                args: [
                    [
                        { type: 'word', value: '1px' },
                        { type: 'space', value: ' ' },
                        { type: 'word', value: 'solid' }
                    ],
                    [
                        { type: 'word', value: 'red' }
                    ]
                ],
                symbolName: 'Button'
            },
            {
                args: null,
                symbolName: 'Mixin'
            }
        ]);
    });
});
//# sourceMappingURL=extend-function-parser.spec.js.map