"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var path_1 = require("path");
var src_1 = require("../src");
var css = "\n    .a{\n        background: url(\"./a.png\")\n    }\n    .b{\n        background: url(\"/b.png\")\n    }\n    .c{\n        background: url(\"data:xxx\")\n    }\n    .d{\n        background: url(\"http://d.ddd\")\n    }\n";
describe('stylable assets', function () {
    it('collect url assets', function () {
        var ast = src_1.safeParse(css);
        chai_1.expect(src_1.collectAssets(ast)).to.eql(['./a.png', '/b.png', 'data:xxx', 'http://d.ddd']);
    });
    it('filter local assets', function () {
        var ast = src_1.safeParse(css);
        chai_1.expect(src_1.collectAssets(ast).filter(src_1.isAsset)).to.eql(['./a.png', '/b.png']);
    });
    it('makeAbsolute', function () {
        var ast = src_1.safeParse(css);
        chai_1.expect(src_1.collectAssets(ast).map(function (_) { return src_1.makeAbsolute(_, '/root', '/root/module'); })).to.eql([
            path_1.normalize('/root/module/a.png'),
            path_1.normalize('/root/b.png'),
            'data:xxx',
            'http://d.ddd'
        ]);
    });
    it('isAsset', function () {
        chai_1.expect(src_1.isAsset('./a.png'), 'relative').to.equal(true);
        chai_1.expect(src_1.isAsset('/a.png'), 'absolute').to.equal(true);
        chai_1.expect(src_1.isAsset('data:'), 'data').to.equal(false);
        chai_1.expect(src_1.isAsset('http://s.sss'), 'url').to.equal(false);
    });
});
//# sourceMappingURL=stylable-assets.spec.js.map