import * as postcss from 'postcss';
import { FileProcessor } from '../../src/cached-process-file';
import { Diagnostics } from '../../src/diagnostics';
import { Stylable } from '../../src/stylable';
import { processNamespace, StylableMeta } from '../../src/stylable-processor';
import { StylableResolver } from '../../src/stylable-resolver';
import { postProcessor, replaceValueHook, StylableResults, StylableTransformer } from '../../src/stylable-transformer';
import { Bundler } from '../../src';
import { Pojo } from '../../src/types';
export interface File {
    content: string;
    mtime?: Date;
    namespace?: string;
}
export interface InfraConfig {
    files: Pojo<File>;
    trimWS?: boolean;
}
export interface Config {
    entry?: string;
    scopeRoot?: boolean;
    files: Pojo<File>;
    usedFiles?: string[];
    trimWS?: boolean;
    optimize?: boolean;
    resolve?: any;
}
export declare type RequireType = (path: string) => any;
export declare function generateInfra(config: InfraConfig, diagnostics?: Diagnostics): {
    resolver: StylableResolver;
    requireModule: RequireType;
    fileProcessor: FileProcessor<StylableMeta>;
};
export declare function createTransformer(config: Config, diagnostics?: Diagnostics, replaceValueHook?: replaceValueHook, postProcessor?: postProcessor): StylableTransformer;
export declare function processSource(source: string, options?: postcss.ProcessOptions, resolveNamespace?: typeof processNamespace): StylableMeta;
export declare function generateFromMock(config: Config, diagnostics?: Diagnostics): StylableResults;
export declare function createProcess(fileProcessor: FileProcessor<StylableMeta>): (path: string) => StylableMeta;
export declare function createTransform(fileProcessor: FileProcessor<StylableMeta>, requireModule: RequireType): (meta: StylableMeta) => StylableMeta;
export declare function generateStylableResult(config: Config): StylableResults;
export declare function generateStylableRoot(config: Config): postcss.Root;
export declare function generateStylableExports(config: Config): Pojo<string>;
export declare function createStylableInstance(config: Config): Stylable;
export declare function createTestBundler(config: Config): Bundler;
export declare function generateStylableOutput(config: Config): string;
//# sourceMappingURL=generate-test-util.d.ts.map